==> apache-asterixdb-0.9.1-source-release.zip: apache-asterixdb-0.9.1/asterix-om/src/main/java/org/apache/asterix/dataflow/data/common/AUnorderedListBinaryTokenizer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.dataflow.data.common;

import org.apache.asterix.common.exceptions.AsterixException;
import org.apache.asterix.dataflow.data.nontagged.serde.AUnorderedListSerializerDeserializer;
import org.apache.hyracks.storage.am.lsm.invertedindex.tokenizers.ITokenFactory;

public class AUnorderedListBinaryTokenizer extends AOrderedListBinaryTokenizer {

    public AUnorderedListBinaryTokenizer(ITokenFactory tokenFactory) {
        super(tokenFactory);
    }

    @Override
    protected int getItemOffset(byte[] data, int start, int itemIndex) throws AsterixException {
        return AUnorderedListSerializerDeserializer.getItemOffset(data, start, itemIndex);
    }

    @Override
    protected int getNumberOfItems(byte[] data, int start) {
        return AUnorderedListSerializerDeserializer.getNumberOfItems(data, start);
    }
}

==> apache-asterixdb-0.9.7-source-release.zip: apache-asterixdb-0.9.7/asterix-om/src/main/java/org/apache/asterix/dataflow/data/common/AUnorderedListBinaryTokenizer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.dataflow.data.common;

import org.apache.asterix.dataflow.data.nontagged.serde.AUnorderedListSerializerDeserializer;
import org.apache.hyracks.api.exceptions.HyracksDataException;
import org.apache.hyracks.storage.am.lsm.invertedindex.tokenizers.ITokenFactory;

public class AUnorderedListBinaryTokenizer extends AOrderedListBinaryTokenizer {

    public AUnorderedListBinaryTokenizer(ITokenFactory tokenFactory) {
        super(tokenFactory);
    }

    @Override
    protected int getItemOffset(byte[] data, int start, int itemIndex) throws HyracksDataException {
        return AUnorderedListSerializerDeserializer.getItemOffset(data, start, itemIndex);
    }

    @Override
    protected int getNumberOfItems(byte[] data, int start) {
        return AUnorderedListSerializerDeserializer.getNumberOfItems(data, start);
    }
}
